Index: /FCKeditor.Java/branches/2.4/java-core/src/main/java/net/fckeditor/FCKeditorConfig.java
===================================================================
--- /FCKeditor.Java/branches/2.4/java-core/src/main/java/net/fckeditor/FCKeditorConfig.java	(revision 1904)
+++ /FCKeditor.Java/branches/2.4/java-core/src/main/java/net/fckeditor/FCKeditorConfig.java	(revision 1905)
@@ -37,5 +37,5 @@
  * the config.js file.
  * 
- * @version $Id: FCKeditorConfig.java 1444 2008-01-28 16:53:01Z mosipov $
+ * @version $Id$
  */
 public class FCKeditorConfig extends HashMap<String, String> {
Index: Keditor.Java/branches/2.4/java-core/src/main/java/net/fckeditor/SessionData.java
===================================================================
--- /FCKeditor.Java/branches/2.4/java-core/src/main/java/net/fckeditor/SessionData.java	(revision 1904)
+++ 	(revision )
@@ -1,83 +1,0 @@
-/*
- * FCKeditor - The text editor for Internet - http://www.fckeditor.net
- * Copyright (C) 2003-2008 Frederico Caldeira Knabben
- * 
- * == BEGIN LICENSE ==
- * 
- * Licensed under the terms of any of the following licenses at your
- * choice:
- * 
- *  - GNU General Public License Version 2 or later (the "GPL")
- *    http://www.gnu.org/licenses/gpl.html
- * 
- *  - GNU Lesser General Public License Version 2.1 or later (the "LGPL")
- *    http://www.gnu.org/licenses/lgpl.html
- * 
- *  - Mozilla Public License Version 1.1 or later (the "MPL")
- *    http://www.mozilla.org/MPL/MPL-1.1.html
- * 
- * == END LICENSE ==
- */
-package net.fckeditor;
-
-import javax.servlet.http.HttpServletRequest;
-
-import net.fckeditor.handlers.ConnectorHandler;
-
-/**
- * Interface to provide session or request based functionality to FCKeditor.Java. Currently, the
- * implemeted class has to implement the following:
- * <ul>
- * <li>{@link #isEnabledForFileBrowsing(HttpServletRequest)}: Enables the user to browse/select
- * file.</li>
- * <li>{@link #isEnabledForFileUpload(HttpServletRequest)}: Enables the user to upload files.</li>
- * <li>{@link #getUserFilesPath(HttpServletRequest)}: It is used by
- * {@link ConnectorHandler#getUserFilesPath(HttpServletRequest)} to build an user based 'BaseDir'.</li>
- * </ul>
- * {@link #isEnabledForFileBrowsing(HttpServletRequest)} and
- * {@link #isEnabledForFileUpload(HttpServletRequest)} are authentification methods for different
- * kinds of user actions.<br />
- * <br />
- * <b>Warning for commiters: </b>You have to awake that every change of this interface could break
- * all classes which implemented this interface. Therefore you should change this interface for
- * milestone releases only!
- * 
- * @version $Id$
- */
-public interface SessionData {
-
-	/**
-	 * Authenticates/enables the current user for uploading file.<br>
-	 * If the implementation doesn't bother you, just return <code>true</code>.
-	 * 
-	 * @param request
-	 *            Servlet request from user
-	 * @return <code>true</code> if user can upload to the server else <code>false</code>
-	 */
-	public boolean isEnabledForFileUpload(final HttpServletRequest request);
-
-	/**
-	 * Authenticates/enables the current user for browsing files.<br>
-	 * If the implementation doesn't bother you, just return <code>true</code>.
-	 * 
-	 * @param request
-	 *            Servlet request from user
-	 * @return <code>true</code> if use can browse the server else <code>false</code>
-	 */
-	public boolean isEnabledForFileBrowsing(final HttpServletRequest request);
-
-	/**
-	 * Getter for the user dependent 'BaseDir'.<br>
-	 * <b>Important:</b>
-	 * <ul>
-	 * <li> If the implementation returns <code>null</code>, {@link ConnectorHandler} will used
-	 * the default one! That's useful, if the implementation doesn't bother you.</li>
-	 * <li>The returned directory string has to start with '/', but has to end without '/'.</li>
-	 * <li>The dir has to be within the context</li>
-	 * </ul>
-	 * 
-	 * @param request
-	 * @return <code>null</code> or the 'BaseDir' string for the current user.
-	 */
-	public String getUserFilesPath(final HttpServletRequest request);
-}
Index: /FCKeditor.Java/branches/2.4/java-core/src/main/java/net/fckeditor/connector/ConnectorServlet.java
===================================================================
--- /FCKeditor.Java/branches/2.4/java-core/src/main/java/net/fckeditor/connector/ConnectorServlet.java	(revision 1904)
+++ /FCKeditor.Java/branches/2.4/java-core/src/main/java/net/fckeditor/connector/ConnectorServlet.java	(revision 1905)
@@ -34,6 +34,6 @@
 import net.fckeditor.handlers.ConnectorHandler;
 import net.fckeditor.handlers.ExtensionsHandler;
+import net.fckeditor.handlers.RequestCycleHandler;
 import net.fckeditor.handlers.ResourceTypeHandler;
-import net.fckeditor.handlers.SessionDataHandler;
 import net.fckeditor.response.UploadResponse;
 import net.fckeditor.response.XmlResponse;
@@ -113,5 +113,5 @@
 		XmlResponse xr;
 
-		if (!SessionDataHandler.isEnabledForFileBrowsing(request))
+		if (!RequestCycleHandler.isEnabledForFileBrowsing(request))
 			xr = new XmlResponse(XmlResponse.EN_ERROR, Messages.NOT_AUTHORIZED_FOR_BROWSING);
 		else if (!CommandHandler.isValidForGet(commandStr))
@@ -209,5 +209,5 @@
 		}
 
-		if (!SessionDataHandler.isEnabledForFileUpload(request))
+		if (!RequestCycleHandler.isEnabledForFileUpload(request))
 			ur = new UploadResponse(UploadResponse.EN_SECURITY_ERROR, null, null,
 			        Messages.NOT_AUTHORIZED_FOR_UPLOAD);
Index: /FCKeditor.Java/branches/2.4/java-core/src/main/java/net/fckeditor/handlers/CommandHandler.java
===================================================================
--- /FCKeditor.Java/branches/2.4/java-core/src/main/java/net/fckeditor/handlers/CommandHandler.java	(revision 1904)
+++ /FCKeditor.Java/branches/2.4/java-core/src/main/java/net/fckeditor/handlers/CommandHandler.java	(revision 1905)
@@ -27,5 +27,5 @@
  * Handler for the get and post commands.
  * 
- * @version $Id: ResourceTypeHandler.java 1606 2008-02-24 17:07:52Z th-schwarz $
+ * @version $Id$
  */
 public class CommandHandler {
Index: /FCKeditor.Java/branches/2.4/java-core/src/main/java/net/fckeditor/handlers/RequestCycleHandler.java
===================================================================
--- /FCKeditor.Java/branches/2.4/java-core/src/main/java/net/fckeditor/handlers/RequestCycleHandler.java	(revision 1905)
+++ /FCKeditor.Java/branches/2.4/java-core/src/main/java/net/fckeditor/handlers/RequestCycleHandler.java	(revision 1905)
@@ -0,0 +1,112 @@
+/*
+ * FCKeditor - The text editor for Internet - http://www.fckeditor.net
+ * Copyright (C) 2003-2008 Frederico Caldeira Knabben
+ * 
+ * == BEGIN LICENSE ==
+ * 
+ * Licensed under the terms of any of the following licenses at your
+ * choice:
+ * 
+ *  - GNU General Public License Version 2 or later (the "GPL")
+ *    http://www.gnu.org/licenses/gpl.html
+ * 
+ *  - GNU Lesser General Public License Version 2.1 or later (the "LGPL")
+ *    http://www.gnu.org/licenses/lgpl.html
+ * 
+ *  - Mozilla Public License Version 1.1 or later (the "MPL")
+ *    http://www.mozilla.org/MPL/MPL-1.1.html
+ * 
+ * == END LICENSE ==
+ */
+package net.fckeditor.handlers;
+
+import javax.servlet.http.HttpServletRequest;
+
+import net.fckeditor.requestcycle.UserAction;
+import net.fckeditor.requestcycle.UserPathBuilder;
+
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
+/**
+ * Handler for classes which implement the interfaces from the package
+ * {@link net.fckeditor.requestcycle}.
+ * 
+ * @version $Id$
+ */
+public class RequestCycleHandler {
+	private static Logger logger = LoggerFactory.getLogger(RequestCycleHandler.class);
+	private static UserAction userAction = null;
+	private static UserPathBuilder userPathBuilder = null;
+
+	static {
+		// If there are more objects to instantiate in future, we could solve the following by reflection!
+		
+		// 1. try to instantiate the UserAction object
+		String fqcn = PropertiesLoader.getProperty("requestcycle.userActionImpl");
+		if (fqcn == null)
+			logger.warn("No property found for UserAction implementation, any user action is disabled!");
+		else {
+			try {
+				@SuppressWarnings("unchecked")
+				Class clazz = Class.forName(fqcn);
+				userAction = (UserAction) clazz.newInstance();
+				logger.info("UserAction object successful instanciated!");
+			} catch (Exception e) {
+				logger.error("Couldn't instanciate the class [".concat(fqcn).concat(
+				        "], any user action of the ConnectorServlet is disabled!"), e);
+			}
+		}
+
+		// 2. try to instantiate the UserPathBuilder object
+		fqcn = PropertiesLoader.getProperty("requestcycle.userPathBuilderImpl");
+		if (fqcn == null)
+			logger.warn("No property found for UserPathBuilder implementation, any user action is disabled!");
+		else {
+			try {
+				@SuppressWarnings("unchecked")
+				Class clazz = Class.forName(fqcn);
+				userPathBuilder = (UserPathBuilder) clazz.newInstance();
+				logger.info("UserPathBuilder object successfull instanciated!");
+			} catch (Exception e) {
+				logger.error("Couldn't instanciate the class ["
+						.concat(fqcn)
+				        .concat("], The default of users's 'BaseDir' will be used in the ConnectorServlet!"), e);
+			}
+		}
+	}
+
+	/**
+	 * Just a wrapper to {@link UserAction#isEnabledForFileBrowsing(HttpServletRequest)}.
+	 * 
+	 * @param servletRequest
+	 * @return {@link UserAction#isEnabledForFileBrowsing(HttpServletRequest)} or false, if
+	 *         sessionData isn't set.
+	 */
+	public static boolean isEnabledForFileBrowsing(final HttpServletRequest servletRequest) {
+		return (userAction != null && userAction.isEnabledForFileBrowsing(servletRequest));
+	}
+
+	/**
+	 * Just a wrapper to {@link UserAction#isEnabledForFileUpload(HttpServletRequest)}.
+	 * 
+	 * @param request
+	 * @return {@link UserAction#isEnabledForFileUpload(HttpServletRequest)} or false, if userAction
+	 *         isn't set.
+	 */
+	public static boolean isEnabledForFileUpload(final HttpServletRequest request) {
+		return (userAction != null && userAction.isEnabledForFileUpload(request));
+	}
+
+	/**
+	 * Getter for the user's file path.<br>
+	 * Method is used by other handlers only!
+	 * 
+	 * @param request
+	 * @return {@link UserPathBuilder#getUserFilesPath(HttpServletRequest)} or null, if
+	 *         userPathBuilder is null.
+	 */
+	protected static String getUserFilePath(final HttpServletRequest request) {
+		return (userPathBuilder != null) ? userPathBuilder.getUserFilesPath(request) : null;
+	}
+}
Index: Keditor.Java/branches/2.4/java-core/src/main/java/net/fckeditor/handlers/SessionDataHandler.java
===================================================================
--- /FCKeditor.Java/branches/2.4/java-core/src/main/java/net/fckeditor/handlers/SessionDataHandler.java	(revision 1904)
+++ 	(revision )
@@ -1,90 +1,0 @@
-/*
- * FCKeditor - The text editor for Internet - http://www.fckeditor.net
- * Copyright (C) 2003-2008 Frederico Caldeira Knabben
- * 
- * == BEGIN LICENSE ==
- * 
- * Licensed under the terms of any of the following licenses at your
- * choice:
- * 
- *  - GNU General Public License Version 2 or later (the "GPL")
- *    http://www.gnu.org/licenses/gpl.html
- * 
- *  - GNU Lesser General Public License Version 2.1 or later (the "LGPL")
- *    http://www.gnu.org/licenses/lgpl.html
- * 
- *  - Mozilla Public License Version 1.1 or later (the "MPL")
- *    http://www.mozilla.org/MPL/MPL-1.1.html
- * 
- * == END LICENSE ==
- */
-package net.fckeditor.handlers;
-
-import javax.servlet.http.HttpServletRequest;
-
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
-
-import net.fckeditor.SessionData;
-
-/**
- * Handler for session based data provided by {@link SessionData}.
- * 
- * @version $Id$
- */
-public class SessionDataHandler {
-	private static Logger logger = LoggerFactory.getLogger(SessionDataHandler.class);
-	private static SessionData sessionData = null;
-
-	static {
-		// try to instanciate the SessionData object
-		String fqcn = PropertiesLoader.getProperty("connector.sessionDataImpl");
-		if (fqcn == null)
-			logger.warn("No property found for SessionData implementation, any user action is disabled!");
-		else {
-			try {
-				@SuppressWarnings("unchecked")
-				Class clazz = Class.forName(fqcn);
-				sessionData = (SessionData) clazz.newInstance();
-				logger.info("SessionData object successfull instanciated!");
-			} catch (Exception e) {
-				logger.error("Couldn't instanciate the class [".concat(fqcn).concat(
-				        "], any user action of the ConnectorServlet is disabled!"), e);
-			}
-		}
-	}
-
-	/**
-	 * Just a wrapper to {@link SessionData#isEnabledForFileBrowsing(HttpServletRequest)}.
-	 * 
-	 * @param servletRequest
-	 * @return {@link SessionData#isEnabledForFileBrowsing(HttpServletRequest)} or false, if
-	 *         sessionData isn't set.
-	 */
-	public static boolean isEnabledForFileBrowsing(final HttpServletRequest servletRequest) {
-		return (sessionData != null && sessionData.isEnabledForFileBrowsing(servletRequest));
-	}
-
-	/**
-	 * Just a wrapper to {@link SessionData#isEnabledForFileUpload(HttpServletRequest)}.
-	 * 
-	 * @param request
-	 * @return {@link SessionData#isEnabledForFileUpload(HttpServletRequest)} or false, if
-	 *         sessionData isn't set.
-	 */
-	public static boolean isEnabledForFileUpload(final HttpServletRequest request) {
-		return (sessionData != null && sessionData.isEnabledForFileUpload(request));
-	}
-
-	/**
-	 * Getter for the user's file path.<br>
-	 * Method is used by other handlers only!
-	 * 
-	 * @param request
-	 * @return {@link SessionData#getUserFilesPath(HttpServletRequest)} or null, if sessionData is
-	 *         null.
-	 */
-	protected static String getUserFilePath(final HttpServletRequest request) {
-		return (sessionData != null) ? sessionData.getUserFilesPath(request) : null;
-	}
-}
Index: /FCKeditor.Java/branches/2.4/java-core/src/main/java/net/fckeditor/requestcycle/UserAction.java
===================================================================
--- /FCKeditor.Java/branches/2.4/java-core/src/main/java/net/fckeditor/requestcycle/UserAction.java	(revision 1905)
+++ /FCKeditor.Java/branches/2.4/java-core/src/main/java/net/fckeditor/requestcycle/UserAction.java	(revision 1905)
@@ -0,0 +1,58 @@
+/*
+ * FCKeditor - The text editor for Internet - http://www.fckeditor.net
+ * Copyright (C) 2003-2008 Frederico Caldeira Knabben
+ * 
+ * == BEGIN LICENSE ==
+ * 
+ * Licensed under the terms of any of the following licenses at your
+ * choice:
+ * 
+ *  - GNU General Public License Version 2 or later (the "GPL")
+ *    http://www.gnu.org/licenses/gpl.html
+ * 
+ *  - GNU Lesser General Public License Version 2.1 or later (the "LGPL")
+ *    http://www.gnu.org/licenses/lgpl.html
+ * 
+ *  - Mozilla Public License Version 1.1 or later (the "MPL")
+ *    http://www.mozilla.org/MPL/MPL-1.1.html
+ * 
+ * == END LICENSE ==
+ */
+package net.fckeditor.requestcycle;
+
+import javax.servlet.http.HttpServletRequest;
+
+
+/**
+ * Interface that can be used to provide user based authenticate some kind of user action:
+ * <ul>
+ * <li>{@link #isEnabledForFileBrowsing(HttpServletRequest)}: Enables the user to browse/select
+ * file.</li>
+ * <li>{@link #isEnabledForFileUpload(HttpServletRequest)}: Enables the user to upload files.</li>
+ * </ul>
+ * 
+ * @version $Id$
+ */
+public interface UserAction {
+
+	/**
+	 * Authenticates/enables the current user for uploading file.<br>
+	 * If the implementation doesn't bother you, just return <code>true</code>.
+	 * 
+	 * @param request
+	 *            Servlet request from user
+	 * @return <code>true</code> if user can upload to the server else <code>false</code>
+	 */
+	public boolean isEnabledForFileUpload(final HttpServletRequest request);
+
+	/**
+	 * Authenticates/enables the current user for browsing files.<br>
+	 * If the implementation doesn't bother you, just return <code>true</code>.
+	 * 
+	 * @param request
+	 *            Servlet request from user
+	 * @return <code>true</code> if use can browse the server else <code>false</code>
+	 */
+	public boolean isEnabledForFileBrowsing(final HttpServletRequest request);
+
+}
Index: /FCKeditor.Java/branches/2.4/java-core/src/main/java/net/fckeditor/requestcycle/UserPathBuilder.java
===================================================================
--- /FCKeditor.Java/branches/2.4/java-core/src/main/java/net/fckeditor/requestcycle/UserPathBuilder.java	(revision 1905)
+++ /FCKeditor.Java/branches/2.4/java-core/src/main/java/net/fckeditor/requestcycle/UserPathBuilder.java	(revision 1905)
@@ -0,0 +1,48 @@
+/*
+ * FCKeditor - The text editor for Internet - http://www.fckeditor.net
+ * Copyright (C) 2003-2008 Frederico Caldeira Knabben
+ * 
+ * == BEGIN LICENSE ==
+ * 
+ * Licensed under the terms of any of the following licenses at your
+ * choice:
+ * 
+ *  - GNU General Public License Version 2 or later (the "GPL")
+ *    http://www.gnu.org/licenses/gpl.html
+ * 
+ *  - GNU Lesser General Public License Version 2.1 or later (the "LGPL")
+ *    http://www.gnu.org/licenses/lgpl.html
+ * 
+ *  - Mozilla Public License Version 1.1 or later (the "MPL")
+ *    http://www.mozilla.org/MPL/MPL-1.1.html
+ * 
+ * == END LICENSE ==
+ */
+package net.fckeditor.requestcycle;
+
+import javax.servlet.http.HttpServletRequest;
+
+import net.fckeditor.handlers.ConnectorHandler;
+
+/**
+ * Interface to provide a way to build a user dependent 'BaseDir.
+ *
+ * @version $Id$
+ */
+public interface UserPathBuilder {
+
+	/**
+	 * Getter for the user dependent 'BaseDir'.<br>
+	 * <b>Important:</b>
+	 * <ul>
+	 * <li> If the implementation returns <code>null</code>, {@link ConnectorHandler} will used
+	 * the default one! That's useful, if the implementation doesn't bother you.</li>
+	 * <li>The returned directory string has to start with '/', but has to end without '/'.</li>
+	 * <li>The dir has to be within the context</li>
+	 * </ul>
+	 * 
+	 * @param request
+	 * @return <code>null</code> or the 'BaseDir' string for the current user.
+	 */
+	public String getUserFilesPath(final HttpServletRequest request);
+}
Index: /FCKeditor.Java/branches/2.4/java-core/src/main/java/net/fckeditor/requestcycle/impl/UserActionImpl.java
===================================================================
--- /FCKeditor.Java/branches/2.4/java-core/src/main/java/net/fckeditor/requestcycle/impl/UserActionImpl.java	(revision 1905)
+++ /FCKeditor.Java/branches/2.4/java-core/src/main/java/net/fckeditor/requestcycle/impl/UserActionImpl.java	(revision 1905)
@@ -0,0 +1,48 @@
+/*
+ * FCKeditor - The text editor for Internet - http://www.fckeditor.net
+ * Copyright (C) 2003-2008 Frederico Caldeira Knabben
+ * 
+ * == BEGIN LICENSE ==
+ * 
+ * Licensed under the terms of any of the following licenses at your
+ * choice:
+ * 
+ *  - GNU General Public License Version 2 or later (the "GPL")
+ *    http://www.gnu.org/licenses/gpl.html
+ * 
+ *  - GNU Lesser General Public License Version 2.1 or later (the "LGPL")
+ *    http://www.gnu.org/licenses/lgpl.html
+ * 
+ *  - Mozilla Public License Version 1.1 or later (the "MPL")
+ *    http://www.mozilla.org/MPL/MPL-1.1.html
+ * 
+ * == END LICENSE ==
+ */
+package net.fckeditor.requestcycle.impl;
+
+import javax.servlet.http.HttpServletRequest;
+
+import net.fckeditor.requestcycle.UserAction;
+
+/**
+ * Standard implementation for {@link UserAction}.
+ *
+ * @version $Id$
+ */
+public class UserActionImpl implements UserAction {
+
+	/* (non-Javadoc)
+	 * @see net.fckeditor.requestcycle.UserAction#isEnabledForFileBrowsing(javax.servlet.http.HttpServletRequest)
+	 */
+	public boolean isEnabledForFileBrowsing(final HttpServletRequest request) {
+		return true;
+	}
+
+	/* (non-Javadoc)
+	 * @see net.fckeditor.requestcycle.UserAction#isEnabledForFileUpload(javax.servlet.http.HttpServletRequest)
+	 */
+	public boolean isEnabledForFileUpload(final HttpServletRequest request) {
+		return true;
+	}
+
+}
Index: /FCKeditor.Java/branches/2.4/java-core/src/main/java/net/fckeditor/requestcycle/impl/UserPathBuilderImpl.java
===================================================================
--- /FCKeditor.Java/branches/2.4/java-core/src/main/java/net/fckeditor/requestcycle/impl/UserPathBuilderImpl.java	(revision 1905)
+++ /FCKeditor.Java/branches/2.4/java-core/src/main/java/net/fckeditor/requestcycle/impl/UserPathBuilderImpl.java	(revision 1905)
@@ -0,0 +1,41 @@
+/*
+ * FCKeditor - The text editor for Internet - http://www.fckeditor.net
+ * Copyright (C) 2003-2008 Frederico Caldeira Knabben
+ * 
+ * == BEGIN LICENSE ==
+ * 
+ * Licensed under the terms of any of the following licenses at your
+ * choice:
+ * 
+ *  - GNU General Public License Version 2 or later (the "GPL")
+ *    http://www.gnu.org/licenses/gpl.html
+ * 
+ *  - GNU Lesser General Public License Version 2.1 or later (the "LGPL")
+ *    http://www.gnu.org/licenses/lgpl.html
+ * 
+ *  - Mozilla Public License Version 1.1 or later (the "MPL")
+ *    http://www.mozilla.org/MPL/MPL-1.1.html
+ * 
+ * == END LICENSE ==
+ */
+package net.fckeditor.requestcycle.impl;
+
+import javax.servlet.http.HttpServletRequest;
+
+import net.fckeditor.requestcycle.UserPathBuilder;
+
+/**
+ * Standard implementation of {@link UserPathBuilder}.
+ *
+ * @version $Id$
+ */
+public class UserPathBuilderImpl implements UserPathBuilder {
+
+	/* (non-Javadoc)
+	 * @see net.fckeditor.requestcycle.UserPathBuilder#getUserFilesPath(javax.servlet.http.HttpServletRequest)
+	 */
+	public String getUserFilesPath(final HttpServletRequest request) {
+		return null;
+	}
+
+}
Index: /FCKeditor.Java/branches/2.4/java-core/src/main/java/net/fckeditor/tags/CheckTag.java
===================================================================
--- /FCKeditor.Java/branches/2.4/java-core/src/main/java/net/fckeditor/tags/CheckTag.java	(revision 1904)
+++ /FCKeditor.Java/branches/2.4/java-core/src/main/java/net/fckeditor/tags/CheckTag.java	(revision 1905)
@@ -32,5 +32,5 @@
 
 import net.fckeditor.handlers.PropertiesLoader;
-import net.fckeditor.handlers.SessionDataHandler;
+import net.fckeditor.handlers.RequestCycleHandler;
 import net.fckeditor.tool.Compatibility;
 
@@ -78,5 +78,5 @@
 
 		if (command.equals(FILE_UPLOAD)) {
-			if (SessionDataHandler.isEnabledForFileUpload(request))
+			if (RequestCycleHandler.isEnabledForFileUpload(request))
 				response = PropertiesLoader
 				        .getProperty(CheckTag.PROPERTY_MESSAGE_FILE_UPLOAD_ENABLED);
@@ -87,5 +87,5 @@
 
 		if (command.equals(FILE_BROWSING)) {
-			if (SessionDataHandler.isEnabledForFileBrowsing(request))
+			if (RequestCycleHandler.isEnabledForFileBrowsing(request))
 				response = PropertiesLoader
 				        .getProperty(CheckTag.PROPERTY_MESSAGE_FILE_BROWSING_ENABLED);
Index: /FCKeditor.Java/branches/2.4/java-demo/src/main/resources/fckeditor.properties
===================================================================
--- /FCKeditor.Java/branches/2.4/java-demo/src/main/resources/fckeditor.properties	(revision 1904)
+++ /FCKeditor.Java/branches/2.4/java-demo/src/main/resources/fckeditor.properties	(revision 1905)
@@ -1,1 +1,2 @@
-connector.sessionDataImpl=net.fckeditor.impl.BasicSessionData
+requestcycle.userActionImpl=net.fckeditor.requestcycle.impl.UserActionImpl
+requestcycle.userPathBuilderImpl=net.fckeditor.requestcycle.impl.UserPathBuilderImpl

Index: /FCKeditor.Java/branches/2.4/java-core/src/main/java/net/fckeditor/handlers/ConnectorHandler.java
===================================================================
--- /FCKeditor.Java/branches/2.4/java-core/src/main/java/net/fckeditor/handlers/ConnectorHandler.java	(revision 1904)
+++ /FCKeditor.Java/branches/2.4/java-core/src/main/java/net/fckeditor/handlers/ConnectorHandler.java	(revision 1905)
@@ -23,8 +23,9 @@
 import javax.servlet.http.HttpServletRequest;
 
-import net.fckeditor.SessionData;
+import net.fckeditor.requestcycle.UserPathBuilder;
 
 /**
- * Handler for some base properties.
+ * Handler for some base properties.<br>
+ * It's a kind of wrapper to some basic properties handled by the {@link PropertiesLoader}.
  * 
  * @version $Id$
@@ -35,9 +36,9 @@
      * Getter for the base dir (using for user files).
      * 
      * @return {@link SessionData#getUserFilesPath(HttpServletRequest)} or the default base dir, if
      *         {@link SessionData}} isn't set.
      */
     public static String getUserFilesPath(final HttpServletRequest servletRequest) {
-    	String userFilePath = SessionDataHandler.getUserFilePath(servletRequest);
+    	String userFilePath = RequestCycleHandler.getUserFilePath(servletRequest);
     	return (userFilePath != null) ? userFilePath : getDefaultUserFilesPath();
     }
@@ -35,9 +36,9 @@
      * Getter for the base dir (using for user files).
      * 
-     * @return {@link SessionData#getUserFilesPath(HttpServletRequest)} or the default base dir, if
-     *         {@link SessionData}} isn't set.
+     * @return {@link UserPathBuilder#getUserFilesPath(HttpServletRequest)} or the default base dir, if
+     *         {@link UserPathBuilder}} isn't set.
      */
     public static String getUserFilesPath(final HttpServletRequest servletRequest) {